# -*- coding: utf-8 -*-

# Copyright (c) ALT-F1 SPRL, Abdelkrim Boujraf. All rights reserved.
# Licensed under the EUPL License, Version 1.2. See LICENSE in the project root for license information.

from .altf1be_json_helpers import AltF1BeJSONHelpers

__all__ = ["AltF1BeJSONHelpers"]


# -*- coding: utf-8 -*-

import os
import json
from pathlib import Path

from datetime import datetime
from altf1be_helpers import AltF1BeHelpers


class AltF1BeJSONHelpers:
    """ Simple helper to load, save and save with date time a JSON file

    """
    @property
    def filename(self):
        return self.__filename

    @filename.setter
    def filename(self, filename):
        self.__filename = os.path.join(
            # AltF1BeHelpers.output_directory(), # TODO remove this line to generalize the management of the files
            filename
        )

    def __init__(self):
        pass

    def save_with_datetime(self, data, filename):
        filename_path = os.path.dirname(filename)
        filename = datetime.now().strftime(
            f'%Y-%m-%d_%H-%M-%S-{os.path.basename(filename)}'
        )
        self.save(
            data=data,
            filename=os.path.join(
                # AltF1BeHelpers.output_directory(
                #     ['api']
                # ),
                filename_path,
                filename
            )
        )

    def save(self, data, filename=None):
        """
            store json file under filename/credentials by default
        """
        if (filename):
            self.filename = filename

        Path(os.path.dirname(self.filename)).mkdir(
            parents=True, exist_ok=True)

        with open(self.filename, 'w', encoding='utf-8') as f:
            json.dump(json.loads(data), f, ensure_ascii=False, indent=4)

    def load(self, filename):
        if (filename):
            self.filename = filename

        with open(self.filename) as json_file:
            data = json.load(json_file)
        return data


if __name__ == "__main__":
    altF1BeJSONHelpers = AltF1BeJSONHelpers()
    data = altF1BeJSONHelpers.load(
        os.path.join(
            "data", "altf1be_sample.json"
        )
    )
    print(data)

    data_str = json.dumps(data)
    altF1BeJSONHelpers.save(
        data_str,
        os.path.join(
            "data", "altf1be_sample_output.json"
        )
    )

    altF1BeJSONHelpers.save_with_datetime(
        data_str,
        os.path.join(
            "data", "altf1be_sample_with_date_time_output.json"
        )
    )



# -*- coding: utf-8 -*-

# Copyright (c) ALT-F1 SPRL, Abdelkrim Boujraf. All rights reserved.
# Licensed under the EUPL License, Version 1.2.
# See LICENSE in the project root for license information.

from os import path
import json
import setuptools
from altf1be_json_helpers.altf1be_json_helpers import AltF1BeJSONHelpers
from altf1be_helpers import AltF1BeHelpers

with open('README.md', 'r') as fh:
    long_description = fh.read()


here = path.abspath(path.dirname(__file__))
root = path.dirname(here)
package_json = path.join(here, 'package.json')
# a workaround when installing locally from git repository with pip install -e .

if not path.isfile(package_json):
    package_json = path.join(root, 'package.json')

# version number and all other params from package.json
with open(package_json, encoding='utf-8') as f:
    package = json.load(f)

setuptools.setup(
    name=package['name'],
    version=package['version'],
    author=package['author']['name'],
    author_email=package['author']['email'],
    description=package['description'],
    license=package['license'],
    long_description=long_description,
    long_description_content_type='text/markdown',
    url=package['homepage'],
    install_requires=AltF1BeHelpers.parse_requirements(f"requirements.txt"),
    packages=[package['name']],
    # package_data={
    #     # If any package contains *.txt files, include them:
    #     # '': ['*.txt'],
    #     # And include any *.dat files found in the 'data' subdirectory
    #     # of the 'mypkg' package, also:
    #     'countries_utils': ['data/*.csv'],
    # },
    keywords=package['keywords'],

    # Find the list of classifiers : https://pypi.org/classifiers/Pyth0n\////
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: European Union Public Licence 1.2 (EUPL 1.2)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],

    # Specify which Python versions you support. In contrast to the
    # 'Programming Language' classifiers above, 'pip install' will check this
    # and refuse to install the project if the version does not match. If you
    # do not support Python 2, you can simplify this to '>=3.5' or similar, see
    # https://packaging.python.org/guides/distributing-packages-using-setuptools/#python-requires
    python_requires='>=3.5',

    # When your source code is in a subdirectory under the project root, e.g.
    # `countries_utils/`, it is necessary to specify the `package_dir` argument.
    # package_dir={'': 'countries_utils'},  # Optional
    # py_modules=['countries_utils'],
    # List additional URLs that are relevant to your project as a dict.
    #
    # This field corresponds to the "Project-URL" metadata fields:
    # https://packaging.python.org/specifications/core-metadata/#project-url-multiple-use
    #
    # Examples listed include a pattern for specifying where the package tracks
    # issues, where the source is hosted, where to say thanks to the package
    # maintainers, and where to support the project financially. The key is
    # what's used to render the link text on PyPI.
    project_urls={  # Optional
        'Bug Reports': 'https://github.com/ALT-F1/altf1be_json_helpers/issues/new',
        'Company behind the library': 'http://www.alt-f1.be',
        'Source': 'https://github.com/ALT-F1/altf1be_json_helpers',
    },

)



# -*- coding: utf-8 -*-

# Copyright (c) ALT-F1 SPRL, Abdelkrim Boujraf. All rights reserved.
# Licensed under the EUPL License, Version 1.2. See LICENSE in the project root for license information.

import os
import unittest
from altf1be_json_helpers import AltF1BeJSONHelpers
from datetime import timedelta, datetime


class AltF1BeJSONHelpersTests(unittest.TestCase):

    """ class for running unittests """

    def setUp(self):
        """ Your setUp """

        self.altF1BeJSONHelpers = AltF1BeJSONHelpers()

        self.expected_json_data = '{"name": "altf1be_json_helpers"}'
        self.json_data = self.altF1BeJSONHelpers.load(
            os.path.join(
                "data", "altf1be_sample.json"
            )
        )

    def test_load_json_file(self):
        """ Test the load of a json file

        """

        self.assertEqual(
            self.expected_json_data['name'],
            self.json_data['name']
        )

    def test_save_json_file(self):
        """ Test the storage of a json file

        """

        self.assertEqual(  # TODO implement the test case
            1,
            1
        )

    def test_save_with_datetime_json_file(self):
        """ Test the storage of a json file appended with a date time

        """

        self.assertEqual(  # TODO implement the test case
            1,
            1
        )


suite = unittest.TestLoader().loadTestsFromTestCase(AltF1BeJSONHelpersTests)
unittest.TextTestRunner(verbosity=2).run(suite)
